@@ -1,4 +1,4 @@
 library(testthat)
 library(devtools)
 
-test_package("rbundler")
+test_check("rbundler")
